@@ -528,7 +528,7 @@ def addOptions(parser: ArgumentParser, config: Optional[Config] = None, jobstore
     core_options.add_argument("--workDir", dest="workDir", default=None,
                               help="Absolute path to directory where temporary files generated during the Toil "
                                    "run should be placed. Standard output and error from batch system jobs "
-                                   "(unless --noStdOutErr) will be placed in this directory. A cache directory "
+                                   "(unless --noStdOutErr is set) will be placed in this directory. A cache directory "
                                    "may be placed in this directory. Temp files and folders will be placed in a "
                                    "directory toil-<workflowID> within workDir. The workflowID is generated by "
                                    "Toil and will be reported in the workflow logs. Default is determined by the "
@@ -1266,27 +1266,55 @@ class Toil(ContextManager["Toil"]):
     def import_file(self,
                     src_uri: str,
                     shared_file_name: str,
-                    symlink: bool = True) -> None: ...
+                    symlink: bool = True,
+                    check_existence: bool = True) -> None: ...
 
     @overload
     def import_file(self,
                     src_uri: str,
                     shared_file_name: None = None,
-                    symlink: bool = True) -> FileID: ...
+                    symlink: bool = True,
+                    check_existence: bool = True) -> FileID: ...
 
     def import_file(self,
                     src_uri: str,
                     shared_file_name: Optional[str] = None,
-                    symlink: bool = True) -> Optional[FileID]:
+                    symlink: bool = True,
+                    check_existence: bool = True) -> Optional[FileID]:
         """
         Import the file at the given URL into the job store.
 
+        By default, returns None if the file does not exist.
+
+        :param check_existence: If true, raise FileNotFoundError if the file
+               does not exist. If false, return None when the file does not
+               exist.
+
         See :func:`toil.jobStores.abstractJobStore.AbstractJobStore.importFile` for a
         full description
         """
         self._assertContextManagerUsed()
-        src_uri = self.normalize_uri(src_uri, check_existence=True)
-        return self._jobStore.import_file(src_uri, shared_file_name=shared_file_name, symlink=symlink)
+        full_uri = self.normalize_uri(src_uri, check_existence=check_existence)
+        try:
+            imported = self._jobStore.import_file(full_uri, shared_file_name=shared_file_name, symlink=symlink)
+        except FileNotFoundError:
+            # TODO: I thought we refactored the different job store import
+            # methods to not raise and instead return None, but that looks to
+            # not currently be the case.
+            if check_existence:
+                raise
+            else:
+                # So translate the raise-based API if needed.
+                # TODO: If check_existence is false but a shared file name is
+                # specified, we have no way to report the lack of file
+                # existence, since we also return None on success!
+                return None
+        if imported is None and shared_file_name is None and check_existence:
+            # We need to protect the caller from missing files.
+            # We think a file was missing, and we got None becasuse of it.
+            # We didn't get None instead because of usign a shared file name.
+            raise FileNotFoundError(f'Could not find file {src_uri}')
+        return imported
 
     @deprecated(new_function_name='export_file')
     def exportFile(self, jobStoreFileID: FileID, dstUrl: str) -> None:
@@ -1308,7 +1336,7 @@ class Toil(ContextManager["Toil"]):
         """
         Given a URI, if it has no scheme, prepend "file:".
 
-        :param check_existence: If set, raise an error if a URI points to
+        :param check_existence: If set, raise FileNotFoundError if a URI points to
                a local file that does not exist.
         """
         if urlparse(uri).scheme == 'file':
